### R code from vignette source 'PanelExercise10.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: RamConstruct
###################################################
##load pwt library
library(pwt)
library(plm)
library(stargazer)

## First replicate based on PWT6.1
data("pwt6.1")

## Create data.frame
data6.1<- data.frame(pwt6.1)

#Subset of years 1960-2000, to match Ram
data6.1.ram <- data.frame(subset(data6.1,data6.1$year>1959 & data6.1$year<2001))

## First see which countries only have a single observation over the entire period
## Ram has 154 countries, but we have 168 countries
uni.country <- unique(data6.1.ram$country)
length(uni.country)

## Now keep only pop, rgdpch and openk (Ram uses openc -- current prices)
## But rgdpch is in chain prices !!#$#@
check.ram <- na.omit(data6.1.ram[,c(1:4,10,15,20,24)])

## Which countries have a single observation
singleyear.store <- as.numeric()

for (i in 1:length(uni.country)){
  
  c.id <- uni.country[i]
	
	singleyear.store[i] <- length(which(check.ram$country==c.id))

}

num.single <- length(which(singleyear.store==1))

## Remove the single year countries
if(num.single>0){

	ram.omit <- uni.country[which(singleyear.store==1)]

	id.omit <- which(check.ram$country%in%ram.omit)
	check.ram <- check.ram[-id.omit,]

}

## Subset of years 1960-2000, to match Ram
pdata6.1.ram <- pdata.frame(check.ram,index=c("country","year"))

## Estimate Pooled OLS 
## Table 1, Column (1)
model1.1 <- plm(log(cg)~log(pop)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram)

## Table 2, Column (1)
model2.1 <- plm(log(openc)~log(pop)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram)

## Table 3, Column (1)
model3.1 <- plm(log(cg)~log(openc)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram)

## Estimate Within 
## Table 1, Column (4)
model1.4 <- plm(log(cg)~log(pop)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram)

## Table 2, Column (4)
model2.4 <- plm(log(openc)~log(pop)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram)

## Table 3, Column (4)
model3.4 <- plm(log(cg)~log(openc)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram)


###################################################
### code chunk number 2: Table1
###################################################
stargazer(model1.1,model1.4,model2.1,
          model2.4,model3.1,model3.4,
          no.space=TRUE,label="table1",
          column.labels=c("Pool","FE","Pool",
                          "FE","Pool","FE"),
          column.separate=c(1,1,1,1,1,1),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"))


###################################################
### code chunk number 3: RamConstruct
###################################################
## Remove the countries with less than 41 time observations
ram.omit <- uni.country[which(singleyear.store<41)]
id.omit <- which(check.ram$country%in%ram.omit)
check.ram1 <- check.ram[-id.omit,]

## Balanced panel from 1960-2000
pdata6.1.ram.bal <- pdata.frame(check.ram1,index=c("country","year"))


## Estimate Pooled OLS 
## Table 1, Column (1)
model1.1 <- plm(log(cg)~log(pop)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram.bal)

## Table 2, Column (1)
model2.1 <- plm(log(openc)~log(pop)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram.bal)

## Table 3, Column (1)
model3.1 <- plm(log(cg)~log(openc)+log(rgdpch),
                model="pool",
                data=pdata6.1.ram.bal)

## Estimate Within 
## Table 1, Column (4)
model1.4 <- plm(log(cg)~log(pop)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram.bal)

## Table 2, Column (4)
model2.4 <- plm(log(openc)~log(pop)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram.bal)

## Table 3, Column (4)
model3.4 <- plm(log(cg)~log(openc)+log(rgdpch),
                model="within",
                effect="twoways",
                data=pdata6.1.ram.bal)

## Estimate Random Effects
## Table 1
model1.rd <- plm(log(cg)~log(pop)+log(rgdpch),
                 model="random",
                 effect="twoways",
                 random.method="walhus",
                 data=pdata6.1.ram.bal)

## Table 2
model2.rd <- plm(log(openc)~log(pop)+log(rgdpch),
                 model="random",
                 effect="twoways",
                 random.method="walhus",
                 data=pdata6.1.ram.bal)

## Table 3
model3.rd <- plm(log(cg)~log(openc)+log(rgdpch),
                 model="random",
                 effect="twoways",
                 random.method="walhus",
                 data=pdata6.1.ram.bal)


###################################################
### code chunk number 4: Table2
###################################################
stargazer(model1.1,model1.4,model1.rd,
          model2.1,model2.4,model2.rd,
          model3.1,model3.4,model3.rd,          
          no.space=TRUE,label="table2",
          column.labels=c("Pool","FE","RD",
                          "Pool","FE","RD",
                          "Pool","FE","RD"),
          column.separate=c(rep(1,9)),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"),
          font.size="scriptsize")


