### R code from vignette source 'PanelExercise11.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
## We first load necessary libraries
library(plm)
library(quantreg)

## Next we load personal codes
source("rqpanel.R")

## Load our data. We use the Grunfeld data in R
data("Grunfeld")

# Then we compute the two step estimator. 
form <- inv ~ value + capital # Equation to be estimated
tau   <- 0.25                 # Quantile to be estimated
two.step <- pqr.estimator(Grunfeld,form,tau,
                          index=c("firm","year"),
                          Y="inv")


###################################################
### code chunk number 2: Mekbib
###################################################
data <- read.csv(file="PanelAreaData.csv",h=T)

data$lMQ <- log(data$Mz_Area)
data$lWP <- log(data$Wh_annualP)
data$lSP <- log(data$Soy_AnnualP)
data$lRP <- log(data$Ric_AnnualP)

## For this example we need a balanced panel
uni.country <- unique(data$country)
length(uni.country)

singleyear.store <- as.numeric()

for (i in 1:length(uni.country)){
  
  c.id <- uni.country[i]
  
	singleyear.store[i] <- length(which(data$country==c.id))

}

omit <- uni.country[which(singleyear.store<50)]
id.omit <- which(data$country%in%omit)
data1 <- data[-id.omit,]

# Then we compute the two step estimator. 
form <- lMQ ~ lWP+lSP+lRP   # Equation to be estimated

two.step.25 <- pqr.estimator(data1,form,tau=0.25,
                          index=c("country","year"),
                          Y="lMQ")

two.step.50 <- pqr.estimator(data1,form,tau=0.50,
                          index=c("country","year"),
                          Y="lMQ")

two.step.75 <- pqr.estimator(data1,form,tau=0.75,
                          index=c("country","year"),
                          Y="lMQ")

## Print out results
two.step.25$prelim

two.step.25$theta
two.step.50$theta
two.step.75$theta


