### R code from vignette source 'PanelExercise4.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
library(plm)

## Load in dataset of Baltagi and Griffin (1983)
data("Gasoline")

## Look at first 6 rows to see the data
head(Gasoline)


###################################################
### code chunk number 2: GasolineCoplot
###################################################
## Now lets plot out gasoline demand over time, conditioning on country
coplot(lgaspcar~year|country,type="b", col="blue",data=Gasoline)

###################################################
### code chunk number 3: GasolineCoplot1
###################################################
## Now lets plot out gasoline demand over time, conditioning on country
coplot(lgaspcar~year|country,type="b", data=Gasoline)

###################################################
### code chunk number 4: Models_Gasoline1
###################################################
gas.pooled <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
                  model="pooling",data=Gasoline)

gas.wn    <- plm(lgaspcar~lincomep+lrpmg+
                   lcarpcap,
                 model="within",effect="individual",
                 data=Gasoline)


###################################################
### code chunk number 5: Models_Gasoline2
###################################################
gas.bw <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
                  model="between",effect="individual",
              data=Gasoline)

gas.rd.nerl <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="nerl",
                     data=Gasoline)

gas.rd.swar <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="swar",
                     data=Gasoline)

gas.rd.wh <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="walhus",
                     data=Gasoline)

gas.rd.amem <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="individual",
                     random.method="amemiya",
                     data=Gasoline)


###################################################
### code chunk number 6: Models_Gasoline3
###################################################
sum.pool <- summary(gas.pooled)
sum.wn   <- summary(gas.wn)
sum.bw   <- summary(gas.bw)
sum.rdsa <- summary(gas.rd.swar)
sum.rdnl <- summary(gas.rd.nerl)
sum.rdam <- summary(gas.rd.amem)
sum.rdwh <- summary(gas.rd.wh)


###################################################
### code chunk number 7: Models_Gasoline4
###################################################
rbind(sum.pool$coefficients[,1],sum.pool$coefficients[,3])

rbind(sum.wn$coefficients[,1],sum.wn$coefficients[,3])

rbind(sum.bw$coefficients[,1],sum.bw$coefficients[,3])

rbind(sum.rdam$coefficients[,1],sum.rdam$coefficients[,3])

rbind(sum.rdwh$coefficients[,1],sum.rdwh$coefficients[,3])

rbind(sum.rdsa$coefficients[,1],sum.rdsa$coefficients[,3])

rbind(sum.rdnl$coefficients[,1],sum.rdnl$coefficients[,3])

## Error Components
sum.rdam$ercomp
sum.rdwh$ercomp
sum.rdsa$ercomp
sum.rdnl$ercomp


###################################################
### code chunk number 8: Models_Gasoline_Lag1
###################################################
gas.pooled.lag <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap+lag(lgaspcar,1),
                  model="pooling",data=Gasoline)

gas.wn.lag    <- plm(lgaspcar~lincomep+lrpmg+
                   lcarpcap+lag(lgaspcar,1),
                 model="within",effect="individual",
                 data=Gasoline)

gas.bw.lag <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap+lag(lgaspcar,1),
                  model="between",effect="individual",
              data=Gasoline)

gas.rd.nerl.lag <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap+lag(lgaspcar,1),
                     model="random",
                     effect="individual",
                     random.method="nerl",
                     data=Gasoline)

gas.rd.swar.lag <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap+lag(lgaspcar,1),
                     model="random",
                     effect="individual",
                     random.method="swar",
                     data=Gasoline)

gas.rd.wh.lag <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap+lag(lgaspcar,1),
                     model="random",
                     effect="individual",
                     random.method="walhus",
                     data=Gasoline)

gas.rd.amem.lag <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap+lag(lgaspcar,1),
                     model="random",
                     effect="individual",
                     random.method="amemiya",
                     data=Gasoline)


###################################################
### code chunk number 9: Models_Gasoline_Lag2
###################################################
sum.pool.lag <- summary(gas.pooled.lag)
sum.wn.lag   <- summary(gas.wn.lag)
sum.bw.lag   <- summary(gas.bw.lag)
sum.rdsa.lag <- summary(gas.rd.swar.lag)
sum.rdnl.lag <- summary(gas.rd.nerl.lag)
sum.rdam.lag <- summary(gas.rd.amem.lag)
sum.rdwh.lag <- summary(gas.rd.wh.lag)

rbind(sum.pool.lag$coefficients[,1],sum.pool.lag$coefficients[,3])

rbind(sum.wn.lag$coefficients[,1],sum.wn.lag$coefficients[,3])

rbind(sum.bw.lag$coefficients[,1],sum.bw.lag$coefficients[,3])

rbind(sum.rdam.lag$coefficients[,1],sum.rdam.lag$coefficients[,3])

rbind(sum.rdwh.lag$coefficients[,1],sum.rdwh.lag$coefficients[,3])

rbind(sum.rdsa.lag$coefficients[,1],sum.rdsa.lag$coefficients[,3])

rbind(sum.rdnl.lag$coefficients[,1],sum.rdnl.lag$coefficients[,3])

## Error Components
sum.rdam.lag$ercomp
sum.rdwh.lag$ercomp
sum.rdsa.lag$ercomp
sum.rdnl.lag$ercomp


