### R code from vignette source 'PanelExercise6.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
library(plm)

## Load in dataset of Baltagi and Griffin (1983)
data("Gasoline")


###################################################
### code chunk number 2: Run
###################################################
gas.pooled <- plm(lgaspcar~lincomep+lrpmg+
                    lcarpcap,
                  model="pooling",data=Gasoline)

gas.wn    <- plm(lgaspcar~lincomep+lrpmg+
                   lcarpcap,
                 model="within",
                 effect="twoways",
                 data=Gasoline)

gas.rd.swar <- plm(lgaspcar~lincomep+lrpmg+
                     lcarpcap,
                     model="random",
                     effect="twoways",
                     random.method="swar",
                     data=Gasoline)

gas.rd.wh <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="twoways",
                     random.method="walhus",
                     data=Gasoline)

gas.rd.amem <- plm(lgaspcar~lincomep+lrpmg+
                       lcarpcap,
                     model="random",
                     effect="twoways",
                     random.method="amemiya",
                     data=Gasoline)


###################################################
### code chunk number 3: Models_Gasoline3
###################################################
sum.pool <- summary(gas.pooled)
sum.wn   <- summary(gas.wn)
sum.rdsa <- summary(gas.rd.swar)
sum.rdam <- summary(gas.rd.amem)
sum.rdwh <- summary(gas.rd.wh)


###################################################
### code chunk number 4: Models_Gasoline4
###################################################
rbind(sum.pool$coefficients[,1],sum.pool$coefficients[,3])

rbind(sum.wn$coefficients[,1],sum.wn$coefficients[,3])

rbind(sum.rdam$coefficients[,1],sum.rdam$coefficients[,3])

rbind(sum.rdwh$coefficients[,1],sum.rdwh$coefficients[,3])

rbind(sum.rdsa$coefficients[,1],sum.rdsa$coefficients[,3])

## Error Components
sum.rdam$ercomp
sum.rdwh$ercomp
sum.rdsa$ercomp

## Test H_{0,3}, individual effects matter, 
## time effects do not

##UNRESTRICTED
gas.wn    <- plm(lgaspcar~lincomep+lrpmg+
                   lcarpcap,
                 model="within",
                 effect="twoways",
                 data=Gasoline)

##RESTRICTED
gas.wn.RES    <- plm(lgaspcar~lincomep+lrpmg+
                   lcarpcap,
                 model="within",
                 effect="individual",
                 data=Gasoline)


###################################################
### code chunk number 5: Munnell_ExampleA
###################################################
library(plm)
data("Produc")

pubcap.data <- Produc

## Take logs of pcap, hwy, water, util, pc, gsp and emp
pubcap.data$lpubc <- log(pubcap.data$pcap)
pubcap.data$lhwy  <- log(pubcap.data$hwy)
pubcap.data$lwatr <- log(pubcap.data$water)
pubcap.data$lutil <- log(pubcap.data$util)
pubcap.data$lprvc <- log(pubcap.data$pc)
pubcap.data$lgsp  <- log(pubcap.data$gsp)
pubcap.data$lemp  <- log(pubcap.data$emp)

## Pooled OLS, no public capital, 
## Cobb-Douglas specification
model.pool1 <- plm(lgsp~lprvc+lemp+unemp,
                   data=pubcap.data,model="pooling")

## Pooled OLS, aggregate public capital, 
##Cobb-Douglas specification
model.pool2 <- plm(lgsp~lprvc+lemp+lpubc+unemp,
                   data=pubcap.data,model="pooling")

## Pooled OLS, decomposed public capital, 
## Cobb-Douglas specification
model.pool3 <- plm(lgsp~lprvc+lemp+lhwy+lwatr+lutil+unemp,
                   data=pubcap.data,model="pooling")

## Fixed Effects Framework, no public capital, 
## Cobb-Douglas specification
model.wn1 <- plm(lgsp~lprvc+lemp+unemp,
                 data=pubcap.data,
                 model="within",effect="twoways")

## Fixed Effects Framework, aggregate public capital, 
## Cobb-Douglas specification
model.wn2 <- plm(lgsp~lprvc+lemp+lpubc+unemp,
                 data=pubcap.data,
                 model="within",effect="twoways")

## Fixed Effects Framework, decomposed public capital, 
## Cobb-Douglas specification
model.wn3 <- plm(lgsp~lprvc+lemp+lhwy+lwatr+lutil+unemp,
                 data=pubcap.data,
                 model="within",effect="twoways")


###################################################
### code chunk number 6: Munnell_ExampleB
###################################################
sum.pool1 <- summary(model.pool1)
sum.pool2 <- summary(model.pool2)
sum.pool3 <- summary(model.pool3)

sum.wn1 <- summary(model.wn1)
sum.wn2 <- summary(model.wn2)
sum.wn3 <- summary(model.wn3)

## Print out Coefficient estimates and t-statistics
sum.pool1$coefficients[,c(1,3)]
sum.pool2$coefficients[,c(1,3)]
sum.pool3$coefficients[,c(1,3)]

sum.wn1$coefficients[,c(1,3)]
sum.wn2$coefficients[,c(1,3)]
sum.wn3$coefficients[,c(1,3)]


