### R code from vignette source 'PanelExercise9.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: Load
###################################################
library(plm)
library(stargazer)

## Load Cigar dataset from Baltagi and Levin (1992)
data("Cigar")

## Estimate pooled model
cig.pool <- plm(log(sales)~lag(log(sales),1)+log(price)+
                  log(ndi)+log(pimin),
                model="pooling",
                data=Cigar)

## Estimate within model
cig.with <- plm(log(sales)~lag(log(sales),1)+log(price)+
                  log(ndi)+log(pimin),
                model="within",
                effect="twoways",
                data=Cigar)

## Estimate FE2SLS model
cig.2SLS <- plm(log(sales)~lag(log(sales),1)+log(price)+
                  log(ndi)+log(pimin)|log(price)+
                  log(ndi)+log(pimin)+lag(log(price),1)+
                  lag(log(ndi),1)+lag(log(pimin),1),
                model="within",
                effect="twoways",
                data=Cigar)

## Dynamic Panel Estimator
## One-step
cig.dyn1 <- pgmm(log(sales)~lag(log(sales),1)+log(price)+
                  log(ndi)+log(pimin)|log(price)+
                  log(ndi)+log(pimin)+lag(log(sales),2:99),
                model="onestep",
                effect="twoways",
                data=Cigar)

## Two-step
cig.dyn2 <- pgmm(log(sales)~lag(log(sales),1)+log(price)+
                  log(ndi)+log(pimin)|log(price)+
                  log(ndi)+log(pimin)+lag(log(sales),2:99),
                model="twosteps",
                effect="twoways",
                data=Cigar)


###################################################
### code chunk number 2: Table1
###################################################
## Create empty summary.plm object since
## stargazer does not support summary.pht

plm.dyn1 <- cig.2SLS
plm.dyn1$coefficients <- cig.dyn1$coefficients[1:4]
plm.dyn1$vcov <- cig.dyn1$vcov[1:4,1:4]

plm.dyn2 <- cig.2SLS
plm.dyn2$coefficients <- cig.dyn2$coefficients[[2]][1:4]
plm.dyn2$vcov <- cig.dyn2$vcov[1:4,1:4]

stargazer(cig.pool,cig.with,cig.2SLS,
          plm.dyn1,plm.dyn2,
          covariate.labels=c("ln C","ln P",
                             "ln Y","ln Pn"),
          keep=c(1,2,3,4),
          no.space=TRUE,label="table1",
          column.labels=c("Pool","FE","FE2SLS",
                          "GMM1","GMM2"),
          column.separate=c(1,1,1,1,1),
          model.numbers=FALSE,
          column.sep.width="2pt",
          omit.stat=c("f"))


